import React, {useContext, useState, useEffect} from 'react'
import styled from 'styled-components'
import { Container } from 'react-grid-system'
import Paper from '@material-ui/core/Paper';
import Button from '@material-ui/core/Button';
import axios from 'axios'
import {apiUrl} from '../../env';
import Bolo from '../../img/Bolo.png'
import LoadingSpinner from '../LoadingSpinner.js'

export default function TabPanelAtividades (props) {
    const [notifications, setNotifications] = useState([]);
    const [notificatonsLength, setLength] = useState(0);
    const [loading, handleLoading] = useState(true)

    useEffect( () => {
        axios.get(`${apiUrl}/feed`, props.config)
        .then( (response) => {
                handleLoading(false)
                //console.log(response)
                setNotifications(response.data)
                //console.log(response.data.length)
                setLength(response.data.length)
            },
            (error) => {
                console.log('error while running getNotifications')
            }
        )
    }, [])

    return (

        <ContainerDivStyled>
            <Paper elevation={3}>
                <div>
                    <DivTitulo>
                        <InnerDivTitulo>
                            <TituloContent>
                                <p style={{margin:"0 0 10px", marginBottom : "40px"}}>Todas Notificações</p>
                            </TituloContent>
                        </InnerDivTitulo>
                    </DivTitulo>
                    {
                        loading ?
                        (
                            <LoadingSpinner text={'Carregando Atividades'}/>
                        )
                        :
                        (
                            [
                                <div>
                                {
                                    notificatonsLength == 0 ?
                                    (
                                        [
                                            <NoNotificationsDiv>
                                            <div>
                                            <div>
                                            <H3Styled><img src={Bolo} alt='bolo' style={{width:"23px"}}/>  Você se cadastrou na Plataforma</H3Styled>
                                            </div>
                                            <p
                                            style={{fontSize:"15px", fontWeight:"lighter", margin:"0 0 10px", display:"flex", justifyContent:"center", textAlign:"center"}}
                                            >Construa conosco a plataforma e amplie sua rede de conhecimento interagindo
                                            <br/>
                                            com pessoas envolvidas com experiências que ocorrem em todo o Brasil!
                                            </p>

                                            </div>
                                            </NoNotificationsDiv>
                                        ]
                                    )
                                    :
                                    (
                                        [   <>
                                            {/*some sort of map with a list of notifications idk what though*/}
                                            <LoadMoreButton><span>CARREGAR MAIS 4</span></LoadMoreButton>
                                            <LoadMoreButton><span>CARREGAR MAIS 20</span></LoadMoreButton>
                                            </>
                                        ]
                                    )
                                }
                                </div>

                            ]
                        )
                }
                </div>
            </Paper>
        </ContainerDivStyled>
    )
}

const H3Styled = styled.h3`
    font-size: 24px;
    font-weight : lighter;
    color : #00bcd4;
    margin-top : 20px;
    margin-bottom : 10px;
    display : flex;
    justify-content : center;
    align-items : center;
`

const NoNotificationsDiv = styled.div`
    height : 250px;
    display: flex;
    align-items : center;
    justify-content : center;
`

const LoadMoreButton = styled(Button)`
    outline : none !important;
    display : inline-block !important;
    cusor : pointer !important;
    min-height : 36px !important;
    min-widht : 88px !important;
    line-height: 36px !important;
    vertical-align: middle !important;
    border : 0 !important;
    padding : 0 px !important;
    margin : 6px 8px !important;
    text-decoration : none !important;
    font-weight : 500 !important;
    overflow : hidden !important;
    text-transform : uppercase !important;
    font-size : 14px !important;
`

const TituloContent = styled.div`
    display : block;
    z-index : 1;
    position : relative;
    font-family: Roboto, sans-serif;
    font-weight : ligther;
`

const InnerDivTitulo = styled.div`
    margin-top : 24px;
    padding-top : 16px;
    padding-left : 16px;
    padding-right : 16px;
    font-size: 30px;
    font-weight: lighter;
    color:  #6e6e6e;
    text-align: center;
`


const DivTitulo = styled.div`
    display : flex;
    justify-content : center;
    font-size: 14px;
    font-weight: 500;
    letter-spacing: .01em;
    line-height: 1.2em;
    margin : 0;
    border-bottom: 1px solid #eee;
`

const ContainerDivStyled = styled.div`
    max-width : 1140px;
    margin-left : auto;
    margin-right : auto;
    margin-left : 20em;
    background-color: #fff;
`
