import React, {useContext, useState, useEffect} from 'react'
import styled from 'styled-components'
import { Container } from 'react-grid-system'
import Paper from '@material-ui/core/Paper';
import Button from '@material-ui/core/Button';
import axios from 'axios'
import {apiUrl} from '../../env';
import LoadingSpinner from '../LoadingSpinner.js'

export default function TabPanelAtividades (props) {
    const [loading, handleLoading] = useState(true)

    const [learningObjects, setLearningObjects] = useState([]);
    const [learningObjectsLength, setLengthLearnObj] = useState(0);

    const [drafts, setDrafts] = useState([]);
    const [draftsLength, setLengthDrafts] = useState(0);

    const [curating, setCurating] = useState([]);
    const [curatingLength, setLengthCurating] = useState(0);

    useEffect( () => {
        axios.all([
            axios.get((`${apiUrl}/users/` + props.id + '/learning_objects'), props.config),
            axios.get((`${apiUrl}/users/` + props.id + '/drafts'), props.config),
            axios.get((`${apiUrl}/users/` + props.id + '/submissions?status=submitted'), props.config)
        ])
        .then( (responseArr) => {
                handleLoading(false)
                console.log(responseArr)
                console.log(responseArr[0].data)
                console.log(responseArr[1].data)
                console.log(responseArr[2].data)

            },
            (error) => {
                handleLoading(false)
                console.log('error while running axios all')
            }
        )
    }, [])


    return (
        <>
            {
                loading ?
                (
                    <LoadingSpinner text={'Carregando Recursos'}/>
                )
                :
                ([
                    <React.Fragment>
                    <ContainerDivStyled>
                    <Paper elevation={3}>

                    <DivTitulo>
                    <StyledP>Recurso Publicado <b style={{fontWeight:"700", fontSize:"20px"}}>({learningObjectsLength})</b></StyledP>
                    <StyledHR/>
                    </DivTitulo>
                    <div>
                    {
                        learningObjectsLength == 0 ?
                        (
                            [
                                <>
                                <DivTextoNoPublications>
                                <DivConteudoNaoPublicado>
                                <NoPubSpan>Você ainda não publicou nenhum Recurso!</NoPubSpan>
                                </DivConteudoNaoPublicado>
                                </DivTextoNoPublications>
                                </>
                            ]
                        )
                        :
                        (
                            <>
                            {/**some sort of map with a list of notifications idk what though**/}
                            <span>stuff goes here</span>
                            </>
                        )

                    }
                    </div>
                    </Paper>
                    </ContainerDivStyled>

                    <ContainerDivStyled>
                    <Paper elevation={3}>
                    <DivTitulo>
                    <StyledP>Rascunhos <b style={{fontWeight:"700", fontSize:"20px"}}>({draftsLength})</b></StyledP>
                    <StyledHR/>
                    </DivTitulo>
                    <div style={{height : "400px"}}>
                    {
                        draftsLength == 0 ?
                        (
                            [
                                <>
                                <DivTextoNoPublications>
                                <DivConteudoNaoPublicado>
                                <NoPubSpan>Você não tem nenhum recurso sendo editado.</NoPubSpan>
                                </DivConteudoNaoPublicado>
                                </DivTextoNoPublications>
                                </>
                            ]
                        )
                        : (
                            [
                                <>
                                <DivContainerRecursosPublicados>
                                </DivContainerRecursosPublicados>
                                <BtnAlinhaRecPvt>
                                <p style={{margin:"0 0 10px", fontSize:"14px"}}>Carregados 4 de 7</p>
                                <ButtonMostrarMais>
                                <span style={{color:"#fff", fontSize:"14px", fontWeight:"500"}}>MOSTRAR MAIS</span>
                                </ButtonMostrarMais>
                                <ButtonMostrarTodos>
                                <span style={{color:"#666", fontSize:"14px", fontWeight:"500"}}>MOSTRAR TODOS</span>
                                </ButtonMostrarTodos>
                                </BtnAlinhaRecPvt>
                                </>
                            ]
                        )
                    }
                    </div>
                    </Paper>
                    </ContainerDivStyled>

                    <ContainerDivStyled>
                    <Paper elevation={3}>

                    <DivTitulo>
                    <StyledP>Recurso sendo avaliado pela curadoria <b style={{fontWeight:"700", fontSize:"20px"}}>({curatingLength})</b></StyledP>
                    <StyledHR/>
                    </DivTitulo>
                    <div>
                    {
                        curatingLength == 0 ?
                        (
                            <DivTextoNoPublications>
                            <DivConteudoNaoPublicado>
                            <NoPubSpan>Você não tem nenhum recurso sendo avaliado pelos curadores.</NoPubSpan>
                            </DivConteudoNaoPublicado>
                            </DivTextoNoPublications>
                        )
                        :
                        (
                            <>
                            {/**some sort of map with a list of notifications idk what though**/}
                            <span>stuff goes here</span>
                            </>
                        )
                    }
                    </div>
                    </Paper>
                    </ContainerDivStyled>
                    </React.Fragment>
                ])
            }
            </>
    )
}

export const ButtonMostrarTodos = styled(Button)`
    &:hover {
        color : #d5d5d5 !important;
    }
    height : 36px !important;
    padding-left: 16px !important;
    padding-right: 16px !important;
    font-weight: 500 !important;
    border-radius: 3px !important;
    color:#666 !important;
    background-color: #e8e8e8 !important;
    min-width : 88px !important;
    height: 36px !important;
`

export const ButtonMostrarMais = styled(Button)`
    background-color : #ff7f00 !important;
    font-size: 14px !important;
    font-weight: 500 !important;
    height: 36px !important;
    border-radius: 3px !important;
    padding-left: 16px !important;
    padding-right: 16px !important;
    box-shadow: 0 2px 5px 0 rgba(0,0,0,.26) !important;
    outline : none !important;
    min-width : 88px !important;
    vertical-align : middle !important;
    margin : 6px 8px !important;
    text-decoration : none !important;
`

export const BtnAlinhaRecPvt = styled.div`
    text-align : center;
    width : 100%;
    float : left;
    position : relative;
    min-height : 1px;
    padding-right : 15px;
    padding-left : 15px;
`

export const DivContainerRecursosPublicados = styled.div`
    width : 100%;
    float : left;
    position : relative;
    min-height : 1px;
    padding-right : 15px;
    padding-left : 15px;
`

export const NoPubSpan = styled.span`
    font-size : 24px;
    font-family : Roboto;
    font-weight : lighter;
`

export const DivConteudoNaoPublicado = styled.div`
    position : relative;
    top : 50%;
    transform : translateY(-50%);
`

export const DivTextoNoPublications = styled.div`
    height : 360px;
    text-align : center;
    width : 100%;
    padding-right : 15px;
    padding-left : 15px;
`

export const StyledHR = styled.hr`
    border-color : #757575;
    border-top: 1px solid #eee;
    margin : 0 15px 0 15px;
    padding-right : 0;
    padding-left : 0;
`

export const StyledP = styled.p`
    text-align : left;
    margin-top : 10px;
    padding-left : 15px;
    padding-right : 15px;
    font-weight : 300;
    font-size : 1.875em;
`

export const DivTitulo = styled.div`
    padding : 0;
    margin-bottom : 10px;
    width : 100;
    display: flex;
    flex-direction : column;
`

export const ContainerDivStyled = styled.div`
    max-width : 1140px;
    margin-left : auto;
    margin-right : auto;
    margin-left : 20em;
    margin-bottom: 30px;
    background-color: #fff;
`
